import program, { Command } from "commander";
import { CommandDefinition } from "../interfaces/command-definition";
interface CommandRegistryConfiguration {
    /**
     * Boolean flag to determine whether the application is being run directly or as a required package.
     *
     * Determines how base commands are registered (whether they are located in the node_modules
     * folder, or the current project directory)
     *
     * @default false
     */
    isImportedModule?: boolean;
}
declare const CommandRegistry: {
    ALIAS_PREFIX: string;
    /**
     * Clears out all command registered with the program.
     *
     * @returns `this` for chaining
     */
    clear(): any;
    /**
     * Update the configuration for the registry. Can be called multiple times as long as the value
     * of 'isImportedModule' is only provided once, or stays the same.
     *
     * @param config Object with various configuration options for the registry
     *
     * @returns `this` for chaining
     */
    configure(config: CommandRegistryConfiguration): any;
    /**
     * Returns a registered command by name. If the command is not registered, returns `undefined`
     *
     * @param {string} name
     */
    get(name: string): program.Command | undefined;
    /**
     * Wrapper around commander's `parse` method to hold additional logic around processing aliases
     * If you don't want to support aliases, using the regular `program.parse(process.argv)` is fine.
     *
     * If no aliases are defined, or no args match defined aliases, it defaults to parsing process.argv
     */
    parseWithAliases(): void;
    /**
     * Register a single command with the program.
     *
     * @param {CommandDefinition} definition
     * @param {boolean} [overrideIfRegistered=false] If true, subsequent registrations of a command
     * with the same name will override the last. Otherwise, a warning will be displayed and the
     * original command will remain.
     *
     * @returns `this` for chaining
     */
    register(definition: CommandDefinition, overrideIfRegistered?: boolean): any;
    /**
     * Registers an alias for another command or command & options. Expects the `CommandDefinition`
     * interface to match existing functions, with the `description` field being the
     * transformed command/command with options.
     *
     * @example
     *  {
     *      command: "testdb",
     *      description: "dotnet --cli -- test db migrate",
     *  }
     *
     * @param definition Command definition where the 'command' field is the desired alias value,
     * and the 'description' field is the transformed command/option string.
     * @param overrideIfRegistered If true, subsequent registrations of a command
     * with the same name will override the last. Otherwise, a warning will be displayed and the
     * original command will remain.
     *
     * @returns `this` for chaining
     */
    registerAlias(definition: CommandDefinition, overrideIfRegistered?: boolean): any;
    /**
     * Registers command aliases from the current `package.json`, if any are found.
     *
     * To add aliases via the package.json file, add entries in this structure:
     *
     * @example
     * {
     *     "and-cli": {
     *          "aliases": {
     *              "testdb": "dotnet --cli -- test db migrate",
     *          },
     *      },
     *  },
     *
     * @param overrideIfRegistered If true, subsequent registrations of a command
     * with the same name will override the last. Otherwise, a warning will be displayed and the
     * original command will remain.
     *
     * @returns `this` for chaining
     */
    registerAliasesFromConfig(overrideIfRegistered?: boolean): any;
    /**
     * Register a set of commands with the program.
     *
     * @param definitions Collection of CommandDefinitions to register with the application
     * @param overrideIfRegistered If true, subsequent registrations of a command
     * with the same name will override the last. Otherwise, a warning will be displayed and the
     * original command will remain.
     *
     * @returns `this` for chaining
     */
    registerAll(definitions: CommandDefinition[] | (Record<string, CommandDefinition> | undefined), overrideIfRegistered?: boolean): any;
    /**
     * Registers all of the base commands available from the `and-cli` with the program.
     * @param overrideIfRegistered If true, subsequent registrations of a command
     * with the same name will override the last. Otherwise, a warning will be displayed and the
     * original command will remain.
     *
     * @returns `this` for chaining
     */
    registerAllBase(overrideIfRegistered?: boolean): any;
    /**
     * Registers a single base command by name available from the `and-cli` with the program.
     *
     * Note: Prints an error if the specified command name is not found.
     *
     * @param name Name of the base command to register
     * @param overrideIfRegistered If true, subsequent registrations of a command
     * with the same name will override the last. Otherwise, a warning will be displayed and the
     * original command will remain.
     *
     * @returns `this` for chaining
     */
    registerBase(name: string, overrideIfRegistered?: boolean): any;
    /**
     * Removes a command from the program by name.
     *
     * @param name Name of the command to remove
     * @returns `this` for chaining
     */
    remove(name: string): any;
};
export { CommandRegistry };
