import { Repository } from "../interfaces/github/repository";
import { Issue } from "../interfaces/github/issue";
import { CreateIssueDto } from "../interfaces/github/create-issue-dto";
import { CloneIssueDestinationDto } from "../interfaces/github/clone-issue-destination-dto";
import { CloneIssueSourceDto } from "../interfaces/github/clone-issue-source-dto";
declare const Github: {
    andcultureOrg: string;
    apiIssuesRouteParam: string;
    apiPullsRouteParam: string;
    apiRepositoriesRouteParam: string;
    apiReviewsRouteParam: string;
    apiRootUrl: string;
    apiTopicsRouteParam: string;
    configAuthConfigPath: string;
    configAuthDocsUrl: string;
    configAuthTokenUrl: string;
    /**
     * Creates an issue for the specified repository
     *
     * @param {CreateIssueDto} dto
     * @returns {(Promise<Issue | undefined>)}
     */
    addIssueToRepository(dto: CreateIssueDto): Promise<Issue | undefined>;
    /**
     * Adds a topic to all AndcultureCode repositories
     *
     * @param {string} topic Topic to be added
     */
    addTopicToAllRepositories(topic?: string | undefined): Promise<void>;
    /**
     * Adds a topic to given repository
     *
     * @param {string} topic Topic to be added
     * @param {string} owner user or organization name owning the repo
     * @param {string} repoName short name of repository (excluding user/organization)
     */
    addTopicToRepository(topic?: string | undefined, owner?: string | undefined, repoName?: string | undefined): Promise<string[] | null | undefined>;
    /**
     * Clones an existing issue to another repository
     *
     * @param {CloneIssueSourceDto} source
     * @param {CloneIssueDestinationDto} destination
     */
    cloneIssueToRepository(source: CloneIssueSourceDto, destination: CloneIssueDestinationDto): Promise<Issue | undefined>;
    /**
     * Sets login token for Github api
     * @param {string} token Github personal access token
     */
    configureToken(token: string): void;
    description(): string;
    /**
     * Retrieves list of pull requests for a repository
     * @param {string} owner user or organization name owning the repo
     * @param {string} repoName name of repository
     * @param {string} state all, closed, open
     */
    getPullRequests(owner?: string | undefined, repoName?: string | undefined, state?: string | undefined): Promise<import("@octokit/types").PullsListResponseData | null>;
    /**
     * Retrieves list of reviews for a pull request
     * @param {string} owner user or organization name owning the repo
     * @param {string} repoName name of repository
     * @param {number} number pull request number
     */
    getPullRequestReviews(owner?: string | undefined, repoName?: string | undefined, number?: number | undefined): Promise<import("@octokit/types").PullsListReviewsResponseData | null | undefined>;
    /**
     * Retrieves a repository
     * @param {string} owner user or organization name owning the repo
     * @param {string} repoName short name of repository (excluding user/organization)
     */
    getRepo(owner: string, repoName: string): Promise<import("@octokit/types").ReposGetResponseData | null>;
    /**
     * Returns a list of Issues for the given repository
     *
     * @param {string} owner
     * @param {string} repoName
     * @returns {(Promise<Issue[] | undefined>)}
     */
    getIssues(owner: string, repoName: string): Promise<Issue[] | undefined>;
    /**
     * Forks a given repository for the current authenticated user
     *
     * While the Github API asychronously forks the repo, our wrapper tries its best to wait for it
     * @param {string} ownerName User or organization that owns the repo being forked
     * @param {string} repoName The 'short' name of the repo (excludes the owner/user/organization)
     */
    fork(ownerName: string, repoName: string): Promise<false | null>;
    /**
     * Retrieves user information of the current authenticated user
     */
    getCurrentUser(): Promise<any>;
    /**
     * Retrieves Github auth token
     */
    getToken(): Promise<string>;
    isTokenConfigured(): Promise<boolean>;
    /**
     * Requests user's Github personal access token
     */
    promptForToken(): Promise<string>;
    /**
     * Lists all AndcultureCode repositories for the given username
     *
     * @param {string} username optional username - if not supplied, retrieves from AndcultureCode organization account
     * @param {function} filter optional filter function to perform on result set
     */
    repositories(username?: string | undefined, filter?: ((repositories: Repository[]) => Repository[]) | undefined): Promise<Repository[] | undefined>;
    /**
     * Removes a topic from all AndcultureCode repositories
     *
     * @param {string} topic Topic to be removed
     */
    removeTopicFromAllRepositories(topic?: string | undefined): Promise<void>;
    /**
     * Removes a topic from a given repository
     *
     * @param {string} topic Topic to be removed
     * @param {string} owner user or organization name owning the repo
     * @param {string} repoName short name of repository (excluding user/organization)
     */
    removeTopicFromRepository(topic?: string | undefined, owner?: string | undefined, repoName?: string | undefined): Promise<string[] | null | undefined>;
    /**
     * Lists all andculture organization repositories
     * @param {string} username optional username of user account. if null, returns main andculture
     * organization repositories
     */
    repositoriesByAndculture(username?: string | undefined): Promise<Repository[] | undefined>;
    /**
     * Lists all repositories for a given organization
     * @param {string} org name of organization. if null, set to andculture organization
     * @param {function} filter optional filter function to perform on result set
     */
    repositoriesByOrganization(org?: string | undefined, filter?: ((repos: Repository[]) => Repository[]) | undefined): Promise<Repository[] | undefined>;
    /**
     * Returns the topics for a specific repository
     *
     * @param {string} ownerName User or organization that owns the repo
     * @param {string} repoName The 'short' name of the repo (excludes the owner/user/organization)
     * @returns {string[] | undefined} Array of topics related to the repository
     */
    topicsForRepository(owner?: string | undefined, repoName?: string | undefined): Promise<string[] | undefined>;
};
export { Github };
