/**
 * Describe/test block for testing functionality of a command triggered by one or more options
 * from an array.
 *
 * @param {string[]} options Array of options to generate `describe` blocks for. Usually a string.
 * @param {(option: string) => void} fn Function to be run nested under the generated `describe` block. Can be
 * a test case or another `describe` block.
 */
declare const givenOptions: (options: string[], fn: (option: string) => void) => void;
/**
 * Test spec ensuring that the given command properly displays the help menu provided by Commander
 *
 * This can be used as a simple 'health check' for parent-level commands to ensure they do not throw
 * runtime errors.
 *
 * @param {string} command The cli command to be run, such as `dotnet` or `webpack`
 * @param {string[]} args Additional args to pass to the command being run, such as `["aws-s3"]`
 * for the `deploy` command
 * @param {boolean=false} debug Optional flag to print the output from the command to the console.
 * @returns
 */
declare const shouldDisplayHelpMenu: (command: string, args?: string[], debug?: boolean) => void;
/**
 * Test spec ensuring that the given function properly returns the error string when run.
 * Defaults to the error constant specified for `echo.error()`, but can be overridden for a more
 * specific error message if needed.
 *
 * @param {async () => string} fn Function to run as the arrange & act steps of the test case. Should return
 * the output to be asserted against.
 * @param {string} [error=ERROR_OUTPUT_STRING] Error message to check for in the result output.
 */
declare const shouldDisplayError: (fn: Function, error?: string) => void;
/**
 * Custom bundling of setup/teardown for a test suite or describe block requiring a temporary directory.
 * Returns the name of the temporary directory and cleanup function if needed for the execution of the test,
 * but will always attempt to run the cleanup function in the `afterEach` step regardless.
 *
 * @param {string} [prefix=""] Optional prefix for the temporary directory to use. Temporary directory
 * is always prefixed with `tmp-`
 * @param {(tmpDir: string) => void} beforeEachFn Optional function to be run at the start of the `beforeEach` block
 * (after the temporary directory has been created)
 * @param {(tmpDir: string) => void} afterEachFn Optional function to be run at the start of the `afterEach` block
 * (before the temporary directory has been cleaned)
 * @returns
 */
declare const withTemporaryDirectory: (prefix?: string, beforeEachFn?: ((tmpDir: string) => void) | undefined, afterEachFn?: ((tmpDir: string) => void) | undefined) => void;
export { givenOptions, shouldDisplayError, shouldDisplayHelpMenu, withTemporaryDirectory, };
