/// <reference types="jest" />
/// <reference types="node" />
import child_process from "child_process";
declare const TestUtils: {
    /**
     * Adds one or more dotnet projects to the solution in the current directory based on the given
     * path. Defaults to \*\*\/*.csproj which will adds all projects in the current directory to the solution.
     *
     * @param {string} path Path pattern to add dotnet projects from.
     */
    addDotnetProject(path?: string | undefined): void;
    /**
     * Creates and enters a temporary working directory. Returns the directory name as well as
     * a cleanup function for resetting the working directory and removing created dir/files.
     *
     * @param {string} [prefix="tmp"] (Optional) Prefix for the directory name to be generated.
     */
    createAndUseTmpDir(prefix?: string): {
        cleanupTmpDir: () => void;
        tmpDir: string;
    };
    /**
     * Uses the dotnet cli to creates a new dotnet solution in the current directory. If no name is
     * provided, it uses the name of the current directory as the solution name.
     *
     * @param {string} [name=""]
     */
    createDotnetSolution(name?: string): void;
    /**
     * Uses the dotnet cli to creates a new dotnet console app in the current directory. If no name is
     * provided, it uses the name of the current directory as the project name.
     *
     * @param {string} [name=""]
     */
    createDotnetConsoleApp(name?: string): void;
    /**
     * Uses the dotnet cli to creates a new XUnit project in the current directory. If no name is
     * provided, it uses the name of the current directory as the project name.
     *
     * @param {string} [name=""]
     */
    createDotnetXUnitProject(name?: string): void;
    /**
     * Wrapper around `child_process.spawn` that passes in the main executable, `and-cli.js`, as the process path.
     * This allows you to pass just the command you're testing in as the first argument.
     *
     * @example
     * const result = await TestUtils.executeCliCommand("dotnet", ["--help"]);
     * @param {string} command
     * @param {string[]} args
     * @param {object} opts
     */
    executeCliCommand(command?: string | undefined, args?: string[], opts?: any): Promise<string>;
    /**
     * Calls `child_process.spawnSync()` with the given args or options. If the process fails,
     * it will throw a fatal error to prevent further execution. Useful for arrangement steps
     * that require setting up data for the system under test.
     *
     * @param {string} processPath
     * @param {string[]} [args=[]]
     * @param {object} [opts={}]
     */
    executeOrThrow(processPath: string, args?: string[], opts?: any): void;
    /**
     * Helper to easily check if tests run in continuous integration environment
     */
    isCI(): boolean;
    /**
     * Helper to easily check if tests run outside of continuous integration environment
     */
    isNotCI(): boolean;
    /**
     * Helper to mock shell response
     * @param {number} code response code from shell command
     * @param {*} stdout
     */
    mockShellFunction(code?: number, stdout?: string): jest.Mock<any, any>;
    /**
     * Wrapper of faker.random.number
     *
     * @param {number} [min=Number.MIN_SAFE_INTEGER] Minimum number value to randomly generate
     * @param {number} [max=Number.MAX_SAFE_INTEGER] Maximum number value to randomly generate
     */
    randomNumber(min?: number, max?: number): number;
    /**
     * Returns a Jest spy instance of the mocked `shell.exit` method
     */
    spyOnShellExit(): jest.SpyInstance<never, [code?: number | undefined]>;
    /**
     *  Returns a Jest spy instance of the mocked `child_process.spawnSync` method
     *
     * @param {number} status Optional exit status for the mocked method to return. Defaults to 0.
     */
    spyOnSpawnSync(status?: number): jest.SpyInstance<child_process.SpawnSyncReturns<Buffer>, [command: string, args?: readonly string[] | undefined, options?: child_process.SpawnSyncOptions | undefined]>;
    randomCase: (str: string) => string;
    randomFilename: () => string;
    randomKey: (obj: any) => string;
    randomObject: (keyCount?: number | undefined) => Record<string, any>;
    randomPath: () => string;
    randomValue: <TValue = any>(obj: any) => TValue;
    randomWord: () => string;
    randomWords: () => string[];
};
export { TestUtils };
